package com.goldenwater.slaj.eutr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eutr.mapper.BisEutrRecMapper;
import com.goldenwater.slaj.eutr.domain.BisEutrRec;
import com.goldenwater.slaj.eutr.service.IBisEutrRecService;

@Service
public class BisEutrRecServiceImpl implements IBisEutrRecService {
    @Autowired
    private BisEutrRecMapper bisEutrRecMapper;

    @Override
    public BisEutrRec selectBisEutrRecByGuid(String guid) {
        return bisEutrRecMapper.selectBisEutrRecByGuid(guid);
    }

    @Override
    public List<BisEutrRec> selectBisEutrRecList(BisEutrRec bisEutrRec) {
        return bisEutrRecMapper.selectBisEutrRecList(bisEutrRec);
    }

    @Override
    public int insertBisEutrRec(BisEutrRec bisEutrRec) {
        return bisEutrRecMapper.insertBisEutrRec(bisEutrRec);
    }

    @Override
    public int updateBisEutrRec(BisEutrRec bisEutrRec) {
        return bisEutrRecMapper.updateBisEutrRec(bisEutrRec);
    }

    @Override
    public int deleteBisEutrRecByGuid(String guid) {
        return bisEutrRecMapper.deleteBisEutrRecByGuid(guid);
    }

    @Override
    public int deleteBisEutrRecByGuids(String[] guids) {
        return bisEutrRecMapper.deleteBisEutrRecByGuids(guids);
    }
}
